@@ -1,12 +1,12 @@
-#  File R/degreedist.R in package ergm.ego, part of the Statnet suite
-#  of packages for network analysis, https://statnet.org .
+#  File R/degreedist.R in package ergm.ego, part of the
+#  Statnet suite of packages for network analysis, https://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
 #  open source, and has the attribution requirements (GPL Section 7) at
-#  https://statnet.org/attribution
+#  https://statnet.org/attribution .
 #
-#  Copyright 2015-2020 Statnet Commons
-#######################################################################
+#  Copyright 2015-2021 Statnet Commons
+################################################################################
 
 
 #' Plotting the degree distribution of an egocentric dataset
@@ -17,7 +17,7 @@
 #' graph.
 #' 
 #' @aliases degreedist
-#' @param object A \code{\link{egodata}} object.
+#' @param object A \code{\link{egor}} object.
 #' @param freq,prob Whether to plot the raw frequencies or the conditional
 #' proportions of the degree values. Defaults to the latter.
 #' @param by A character vector giving the name of a vertex attribute; if
@@ -26,8 +26,8 @@
 #' according to a Bernoulli graph having the same expected density as the
 #' observed.
 #' @param main Main title of the plot.
-#' @param plot Whether to plot the histogram; if `FALSE`, graphical
-#'   parameters and `bgrmod` have no effect.
+#' @param plot Whether to plot the histogram; defaults to the same
+#'   value as`brgmod`, i.e., `FALSE`.
 #' @param weight Whether sampling weights should be incorporated into
 #'   the calculation (`TRUE`, the default) or ignored (`FALSE`).
 #' @param ... Additional arguments to [simulate.ergm.ego()].
@@ -41,41 +41,33 @@
 #' @examples
 #' 
 #' data(faux.mesa.high)
-#' fmh.ego <- as.egodata(faux.mesa.high)
+#' fmh.ego <- as.egor(faux.mesa.high)
 #' 
 #' degreedist(fmh.ego,by="Grade",brgmod=TRUE)
 #' # Compare:
 #' degreedist(faux.mesa.high)
 #' 
 #' @importFrom graphics arrows barplot legend points
+#' @importFrom methods is
 #' @export
-degreedist.egodata <- function(object, freq = FALSE, prob = !freq, 
-                               by = NULL, brgmod = FALSE, main = NULL, plot = TRUE, weight = TRUE, ...){
-  egodata <- object
-  if(!weight) egodata$egoWt[] <- 1
-
+degreedist.egor <- function(object, freq = FALSE, prob = !freq, 
+                            by = NULL, brgmod = FALSE, main = NULL, plot = brgmod, weight = TRUE, ...){
   color <- "#83B6E1"
   beside <- TRUE
 
   ylabel <- if(prob) "Proportion" else "Frequency"
   if(!is.null(by)) ylabel <- paste(ylabel, "(within attr level)")
 
-  egoIDcol <- egodata$egoIDcol
-  
-  egodata$egos[[egoIDcol]] <- factor(egodata$egos[[egoIDcol]])
-  egodata$alters[[egoIDcol]] <- factor(egodata$alters[[egoIDcol]], levels=levels(egodata$egos[[egoIDcol]])) 
-  egodata$egos[[egoIDcol]] <- as.integer(egodata$egos[[egoIDcol]])
-  egodata$alters[[egoIDcol]] <- as.integer(egodata$alters[[egoIDcol]])
-  
-  degtable <- rep(0, nrow(egodata$egos))
-  degtable[as.numeric(names(table(egodata$alters[egoIDcol])))] <- table(egodata$alters[egoIDcol])
+  degtable <- .degreeseq(object)
+
+  w <- if(weight) weights(object) else rep(1, nrow(object$ego))
   
   if(is.null(by)){
-    deg.ego <- xtabs(egodata$egoWt~degtable)
+    deg.ego <- xtabs(w~degtable)
     names(dimnames(deg.ego)) <- "degree"
     degrees <- as.integer(names(deg.ego))
   }else{
-    deg.ego <- xtabs(egodata$egoWt~egodata$egos[[by]]+degtable)
+    deg.ego <- xtabs(w~as_tibble(object$ego)[[by]]+degtable)
     names(dimnames(deg.ego)) <- c(by, "degree")
     levs <- rownames(deg.ego)
     degrees <- as.integer(colnames(deg.ego))
@@ -106,11 +98,11 @@ degreedist.egodata <- function(object, freq = FALSE, prob = !freq,
       beside <- TRUE
     }
   }
-
+  
   if(plot){
     if(brgmod) {
-      ppopsize.mul <- max(egodata$egoWt)/min(egodata$egoWt)
-      brgdraws <- simulate(suppressMessages(ergm.ego(egodata ~ edges, control=control.ergm.ego(ppopsize=nrow(egodata$egos)*ppopsize.mul))), nsim = 50, ...)
+      ppopsize.mul <- max(w)/min(w)
+      brgdraws <- simulate(suppressMessages(ergm.ego(object ~ edges, control=control.ergm.ego(ppopsize=nrow(object$ego)*ppopsize.mul))), nsim = 50, ...)
       deg.brg <- summary(brgdraws ~ degree(degrees))/ppopsize.mul
       brgmeans <- apply(deg.brg, MARGIN = 2, FUN = mean)
       brgsd <- apply(deg.brg, MARGIN = 2, FUN = sd)
@@ -127,7 +119,6 @@ degreedist.egodata <- function(object, freq = FALSE, prob = !freq,
           lower <- lower/sum(brgmeans)
           brgmeans <- brgmeans/sum(brgmeans)
         }
-        
       }
       maxfreq <- max(maxfreq, upper, na.rm = TRUE)
     }
@@ -163,12 +154,12 @@ degreedist.egodata <- function(object, freq = FALSE, prob = !freq,
 #' Summarizing the mixing among groups in an egocentric dataset
 #' 
 #' A \code{\link[network]{mixingmatrix}} method for
-#' \code{\link{egodata}} objects, to return counts of how often a ego
+#' \code{\link{egor}} objects, to return counts of how often a ego
 #' of each group nominates an alter of each group.
 #' 
 #' 
 #' @aliases mixingmatrix
-#' @param object A \code{\link{egodata}} object.
+#' @param object A \code{\link{egor}} object.
 #' @param attrname A character vector containing the name of the network
 #' attribute whose mixing matrix is wanted.
 #' @param rowprob Whether the counts should be normalized by row sums. That is,
@@ -180,50 +171,34 @@ degreedist.egodata <- function(object, freq = FALSE, prob = !freq,
 #' 
 #' Note that, unlike \code{\link[network]{mixingmatrix}}, what is counted are
 #' \emph{nominations}, not ties. This means that under an egocentric census,
-#' the diagonal of \code{mixingmatrix.egodata} will be twice that returned by
+#' the diagonal of \code{mixingmatrix.egor} will be twice that returned by
 #' \code{\link[network]{mixingmatrix}} for the original undirected network.
 #' @seealso \code{\link[network]{mixingmatrix}}, \code{\link[ergm]{nodemix}},
 #' \code{\link[ergm.ego]{summary}} method for egocentric data
 #' @examples
 #' 
 #' data(faux.mesa.high)
-#' fmh.ego <- as.egodata(faux.mesa.high)
+#' fmh.ego <- as.egor(faux.mesa.high)
 #' 
 #' (mm <- mixingmatrix(faux.mesa.high,"Grade"))
 #' (mm.ego <- mixingmatrix(fmh.ego,"Grade"))
 #' 
-#' stopifnot(isTRUE(all.equal({tmp<-unclass(mm$matrix); diag(tmp) <- diag(tmp)*2;
-#' tmp}, mm.ego, check.attributes=FALSE)))
-#' 
 #' @export
-mixingmatrix.egodata <- function(object, attrname, rowprob = FALSE, weight = TRUE, ...){
-  egodata <- object
-  if(!weight) egodata$egoWt[] <- 1
+mixingmatrix.egor <- function(object, attrname, rowprob = FALSE, weight = TRUE, ...){
+  ds <- .degreeseq(object)
+  egos <- rep(.unfactor(as_tibble(object$ego)[[attrname]]), ds)
+  alters <- .unfactor(object$alter[[attrname]])
+  levs <- sort(unique(c(egos,alters)))
+
+  w <- if(weight) rep(weights(object),ds) else rep(1, nrow(object$alter))
+
+  mxmat <- outer(levs, levs, Vectorize(function(l1, l2) sum(w[egos==l1&alters==l2])))
 
-  egos <- egodata$egos
-  alters <- egodata$alters
-  egoIDcol <- egodata$egoIDcol
-  
-  levs <- sort(unique(c(egos[[attrname]], alters[[attrname]])))
-  egos[[attrname]] <- match(egos[[attrname]], levs, 0)
-  alters[[attrname]] <- match(alters[[attrname]], levs, 0)
-  
-  ties <- merge(egos[c(egoIDcol,attrname)], alters[c(egoIDcol,attrname)], 
-                by = egoIDcol, suffixes = c(".ego",".alter"))
-  ties$wt <- object$egoWt[match(ties[[egoIDcol]],egos[[egoIDcol]])]
-  mxmat <- matrix(0, nrow = length(levs), ncol = length(levs))
-  
-  for(i in 1:length(levs)){
-    for(j in 1:length(levs)){
-      mxmat[i,j] <- sum(ties$wt[ties[,2]==i & ties[,3]==j])
-    }
-  }
   dimnames(mxmat) <- list(ego = levs,  
                           alter = levs)
   if(rowprob){
     mxmat <- mxmat/rowSums(mxmat)
   }
-  mxmat
+  structure(mxmat, class = c("mixingmatrix", "table"), directed = FALSE,
+            bipartite = FALSE)
 }
-  
-  
