@@ -1,12 +1,12 @@
-#  File R/predict.ergmego.R in package ergm.ego, part of the Statnet suite
-#  of packages for network analysis, https://statnet.org .
+#  File R/predict.ergmego.R in package ergm.ego, part of the
+#  Statnet suite of packages for network analysis, https://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
 #  open source, and has the attribution requirements (GPL Section 7) at
-#  https://statnet.org/attribution
+#  https://statnet.org/attribution .
 #
-#  Copyright 2015-2020 Statnet Commons
-#######################################################################
+#  Copyright 2015-2021 Statnet Commons
+################################################################################
 #' ERGM-based predicted tie probabilities for the pseudo-population network
 #' 
 #' @param object model fit as returned by [ergm.ego()]
@@ -23,6 +23,6 @@ predict.ergm.ego <- function(object, ...) {
   frm <- statnet.common::nonsimp_update.formula(object$ergm.formula, net ~ .)
   assign("net", object$network, envir=environment(frm))
   # thetas
-  th <- ergm.eta(object$coef, object$etamap)
+  th <- ergm.eta(coef(object), object$etamap)
   predict(frm, theta=th, ...)
 }
