@@ -1,18 +1,18 @@
-#  File tests/testthat/test-predict.ergm.ego.R in package ergm.ego, part of the Statnet suite
-#  of packages for network analysis, https://statnet.org .
+#  File tests/testthat/test-predict.ergm.ego.R in package ergm.ego, part of the
+#  Statnet suite of packages for network analysis, https://statnet.org .
 #
 #  This software is distributed under the GPL-3 license.  It is free,
 #  open source, and has the attribution requirements (GPL Section 7) at
-#  https://statnet.org/attribution
+#  https://statnet.org/attribution .
 #
-#  Copyright 2015-2020 Statnet Commons
-#######################################################################
+#  Copyright 2015-2021 Statnet Commons
+################################################################################
 
 library(ergm.ego)
 
 test_that("it just works for model without offsets", {
   data(faux.mesa.high, package="ergm")
-  fmh.ego <- as.egodata(faux.mesa.high)
+  fmh.ego <- as.egor(faux.mesa.high)
   egofit <- ergm.ego(
     fmh.ego~edges+degree(0:3)+nodefactor("Race")+nodematch("Race")
     +nodefactor("Sex")+nodematch("Sex")+absdiff("Grade"), 
@@ -27,7 +27,7 @@ test_that("it just works for model without offsets", {
 
 test_that("it just works for model with offsets", {
   data("faux.mesa.high", package="ergm")
-  fmhego <- as.egodata(faux.mesa.high)
+  fmhego <- as.egor(faux.mesa.high)
   fit <- ergm.ego(
     fmhego ~ edges 
     + nodefactor("Grade")
